import { defineComponent, onMounted, reactive } from 'vue';
import styles from './index.module.less';
import CardType from '/src/components/card-type';
import Pagination from '/src/components/pagination';
import SearchGroupResources from './search-group-resources';
import { materialQueryPage } from '../../api';
import { NEmpty, NSpin } from 'naive-ui';
import TheEmpty from '/src/components/TheEmpty';

export default defineComponent({
  name: 'share-resources',
  setup() {
    const state = reactive({
      searchWord: '',
      loading: false,
      pageTotal: 0,
      pagination: {
        page: 1,
        rows: 20
      },
      searchGroup: {
        type: '', //
        keyword: '',
        bookVersionId: null,
        subjectId: null,
        sourceType: 4
      },
      tableList: [] as any
    });
    const getList = async () => {
      try {
        state.loading = true;
        const { data } = await materialQueryPage({
          ...state.searchGroup,
          ...state.pagination
        });
        state.loading = false;
        state.pageTotal = Number(data.total);
        state.tableList = data.rows || [];
      } catch {
        state.loading = false;
      }
    };

    const onSearch = async (item: any) => {
      state.pagination.page = 1;
      state.searchGroup = Object.assign(state.searchGroup, item);
      console.log(item, state.searchGroup);
      getList();
    };

    onMounted(() => {
      getList();
    });
    return () => (
      <>
        <SearchGroupResources onSearch={(item: any) => onSearch(item)} />

        <NSpin v-model:show={state.loading}>
          <div class={styles.list}>
            {state.tableList.map((item: any) => {
              const tmpItem = {
                id: item.id,
                coverImg: item.coverImg,
                type: item.type,
                title: item.name,
                isCollect: !!item.favoriteFlag,
                isSelected: item.sourceFrom === 'PLATFORM' ? true : false
              };
              return <CardType item={tmpItem} />;
            })}

            {!state.loading && state.tableList.length <= 0 && (
              <TheEmpty description="暂无收藏资源" />
            )}
          </div>
        </NSpin>

        <Pagination
          v-model:page={state.pagination.page}
          v-model:pageSize={state.pagination.rows}
          v-model:pageTotal={state.pageTotal}
          onList={getList}
        />
      </>
    );
  }
});
