import { defineComponent, onMounted, reactive, ref } from 'vue';
import styles from './index.module.less';
import { NButton, NForm, NFormItem, NSpace } from 'naive-ui';
import iconAdd from '../../images/icon-add.svg';
import TheSearch from '/src/components/TheSearch';
import { resourceTypeArray } from '/src/utils/searchArray';

export default defineComponent({
  name: 'search-group',
  emits: ['search'],
  setup(props, { emit }) {
    const forms = reactive({
      type: 'MUSIC', //
      keyword: '',
      bookVersionId: null,
      subjectId: null
    });

    const onSearch = () => {
      emit('search', forms);
    };

    return () => (
      <div class={styles.searchGroup}>
        <div class={styles.searchCatatory}>
          <NSpace size="small" class={styles.btnType}>
            {resourceTypeArray.map((item: any) => (
              <NButton
                type={forms.type === item.value ? 'primary' : 'default'}
                secondary={forms.type === item.value ? false : true}
                round
                size="small"
                focusable={false}
                onClick={() => {
                  forms.type = item.value;
                  onSearch();
                }}>
                {item.label}
              </NButton>
            ))}
          </NSpace>

          <NButton
            type="primary"
            class={styles.addTrain}
            focusable={false}
            strong>
            <img src={iconAdd} />
            添加自定义教材
          </NButton>
        </div>
        <NForm labelAlign="left" labelPlacement="left">
          <NFormItem label="教材：">
            <NSpace>
              <NButton secondary strong type="primary" focusable={false}>
                全部
              </NButton>
              <NButton quaternary focusable={false}>
                人教版
              </NButton>
              <NButton quaternary focusable={false}>
                声部训练
              </NButton>
              <NButton quaternary focusable={false}>
                小曲目
              </NButton>
              <NButton quaternary focusable={false}>
                考级曲目
              </NButton>
            </NSpace>
          </NFormItem>
          <NFormItem label="乐器：">
            <NSpace>
              <NButton secondary strong type="primary">
                全部
              </NButton>
              <NButton quaternary focusable={false} type="default">
                竖笛
              </NButton>
              <NButton quaternary focusable={false} type="default">
                排萧
              </NButton>
              <NButton quaternary focusable={false} type="default">
                口风琴
              </NButton>
              <NButton quaternary focusable={false} type="default">
                陶笛
              </NButton>
              <NButton quaternary focusable={false} type="default">
                葫芦丝
              </NButton>
            </NSpace>
          </NFormItem>

          <TheSearch
            class={styles.inputSearch}
            round
            onSearch={(val: string) => {
              forms.keyword = val;
              onSearch();
            }}
          />
        </NForm>
      </div>
    );
  }
});
